==> bergen-0.3.67.tar.gz: bergen-0.3.67/bergen/messages/types.py <==
#Base Types
EXCEPTION = "exception"
ALLOWANCE = "allowance"

ASSIGNATION = "assignation"
PROVISION = "provision"
ASSIGNATION_REQUEST = "assignation_request"
PROVISION_REQUEST = "provision_request"

ACTIVATE_POD = "activate_pod"
DEACTIVATE_POD ="deactivate_pod"


# ASIGN PATH
ASSIGN = "assign"
CANCEL_ASSIGN = "cancel_assign"

BOUNCED_ASSIGN = "bounced_assign"
BOUNCED_CANCEL_ASSIGN = "bounced_cancel_assign"

ASSIGN_DONE = "assign_done"
ASSIGN_PROGRES ="assign_progress"
ASSIGN_CRITICAL = "assign_fail"
ASSIGN_YIELD =  "assign_yield"
ASSIGN_RETURN = "assign_return"
ASSIGN_RETRY = "assign_retry"



# Reserve
RESERVE = "reserve"
BOUNCED_RESERVE = "bounced_reserve"


CANCEL_RESERVE = "cancel_reserve"
BOUNCED_CANCEL_RESERVE = "bounced_cancel_reserve" # TODO: Deprecated

RESERVE_DONE = "reserve_done"
RESERVE_PROGRESS = "reserve_progress"
RESERVE_FAIL = "reserve_fail"
RESERVE_CRITICAL = "reserve_critical"


#Unreserve

UNRESERVE = "unreserve"
BOUNCED_UNRESERVE = "bounced_unreserve"

CANCEL_UNRESERVE = "cancel_unreserve"
BOUNCED_CANCEL_UNRESERVE = "bounced_cancel_unreserve" # TODO: Deprecated

UNRESERVE_DONE = "unreserve_done"
UNRESERVE_PROGRESS = "unreserve_progress"
UNRESERVE_FAIL = "unreserve_fail"
UNRESERVE_CRITICAL = "unreserve_critical"


# Provide
PROVIDE = "provide"
CANCEL_PROVIDE = "cancel_provide"

BOUNCED_PROVIDE = "bounced_provide"
BOUNCED_CANCEL_PROVIDE = "bounced_cancel_provide"

PROVIDE_DONE = "provide_done"
PROVIDE_PROGRESS = "provide_progress"
PROVIDE_FAIL = "provide_fail"
PROVIDE_CRITICAL = "provide_critical"

# Unprovide
UNPROVIDE = "unprovide"
BOUNCED_UNPROVIDE = "bounced_unprovide"

CANCEL_UNPROVIDE = "unprovide_cancel"
BOUNCED_CANCEL_UNPROVIDE = "bounced_cancel_unprovide"


UNPROVIDE_DONE = "unprovide_done"
UNPROVIDE_PROGRESS = "unprovide_progress"
UNPROVIDE_FAIL = "unprovide_fail"
UNPROVIDE_CRITICAL = "unprovide_critical"

==> bergen-0.3.140.tar.gz: bergen-0.3.140/bergen/messages/types.py <==
#Base Types
EXCEPTION = "exception"
ALLOWANCE = "allowance"

ASSIGNATION = "assignation"
PROVISION = "provision"
ASSIGNATION_REQUEST = "assignation_request"
PROVISION_REQUEST = "provision_request"

ACTIVATE_POD = "activate_pod"
DEACTIVATE_POD ="deactivate_pod"


# ASIGN PATH
ASSIGN = "assign"
BOUNCED_ASSIGN = "bounced_assign"
BOUNCED_FORWARDED_ASSIGN = "bounced_forwarded_assign"

ASSIGN_DONE = "assign_done"
ASSIGN_CANCELLED = "assign_cancelled"
ASSIGN_PROGRES ="assign_progress"
ASSIGN_CRITICAL = "assign_fail"
ASSIGN_YIELD =  "assign_yield"
ASSIGN_RETURN = "assign_return"
ASSIGN_RETRY = "assign_retry"

# UNASSIGN PATH
UNASSIGN = "unassign"
BOUNCED_UNASSIGN = "bounced_unassign"

UNASSIGN_DONE = "unassign_done"
UNASSIGN_PROGRES ="unassign_progress"
UNASSIGN_CRITICAL = "unassign_fail"

# Reserve
RESERVE = "reserve"
BOUNCED_RESERVE = "bounced_reserve"
BOUNCED_FORWARDED_RESERVE = "bounced_forwarded_reserve"

RESERVE_DONE = "reserve_done"
RESERVE_PROGRESS = "reserve_progress"
RESERVE_FAIL = "reserve_fail"
RESERVE_CRITICAL = "reserve_critical"


#Unreserve
UNRESERVE = "unreserve"
BOUNCED_UNRESERVE = "bounced_unreserve"

UNRESERVE_DONE = "unreserve_done"
UNRESERVE_PROGRESS = "unreserve_progress"
UNRESERVE_FAIL = "unreserve_fail"
UNRESERVE_CRITICAL = "unreserve_critical"


# Provide
PROVIDE = "provide"
BOUNCED_PROVIDE = "bounced_provide"

PROVIDE_DONE = "provide_done"
PROVIDE_PROGRESS = "provide_progress"
PROVIDE_FAIL = "provide_fail"
PROVIDE_CRITICAL = "provide_critical"

# Unprovide
UNPROVIDE = "unprovide"
BOUNCED_UNPROVIDE = "bounced_unprovide"

UNPROVIDE_DONE = "unprovide_done"
UNPROVIDE_PROGRESS = "unprovide_progress"
UNPROVIDE_FAIL = "unprovide_fail"
UNPROVIDE_CRITICAL = "unprovide_critical"
